@@ -1,21 +1,7 @@
 /*
- *   Copyright 2017, 2018, 2019 by Ivan Cukic <ivan.cukic (at) kde.org>
+ *   SPDX-FileCopyrightText: 2017, 2018, 2019 Ivan Cukic <ivan.cukic (at) kde.org>
  *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License or (at your option) version 3 or any later version
- *   accepted by the membership of KDE e.V. (or its successor approved
- *   by the membership of KDE e.V.), which shall act as a proxy
- *   defined in Section 14 of version 3 of the license.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef PLASMAVAULT_PLASMA_VAULTSMODEL_H
@@ -28,7 +14,8 @@
 
 #include <common/vaultinfo.h>
 
-class VaultsModel: public QAbstractListModel {
+class VaultsModel : public QAbstractListModel
+{
     Q_OBJECT
 
     Q_PROPERTY(bool isBusy READ isBusy NOTIFY isBusyChanged)
@@ -50,16 +37,16 @@ public:
 
     enum Roles {
         VaultName = Qt::UserRole + 1, ///< The user defined name of the vault
-        VaultDevice,                  ///< Path to the encrypted data
-        VaultMountPoint,              ///< Where the data should be visible from
-        VaultIcon,                    ///< Icon for the fault
-        VaultIsBusy,                  ///< Is the vault currently being opened or closed
-        VaultIsOpened,                ///< Is the vault open
-        VaultStatus,                  ///< Status of the vault, @see VaultInfo::Status
-        VaultActivities,              ///< To which activities does this vault belong to
-        VaultIsOfflineOnly,           ///< Should the networking be off when this vault is mounted
-        VaultMessage,                 ///< Message to be shown for the vault
-        VaultIsEnabled                ///< Can the vault be mounted
+        VaultDevice, ///< Path to the encrypted data
+        VaultMountPoint, ///< Where the data should be visible from
+        VaultIcon, ///< Icon for the fault
+        VaultIsBusy, ///< Is the vault currently being opened or closed
+        VaultIsOpened, ///< Is the vault open
+        VaultStatus, ///< Status of the vault, @see VaultInfo::Status
+        VaultActivities, ///< To which activities does this vault belong to
+        VaultIsOfflineOnly, ///< Should the networking be off when this vault is mounted
+        VaultMessage, ///< Message to be shown for the vault
+        VaultIsEnabled, ///< Can the vault be mounted
     };
 
 public Q_SLOTS:
@@ -86,7 +73,6 @@ public Q_SLOTS:
     // Open in file manager
     void openInFileManager(const QString &device);
 
-
     bool isBusy() const;
     bool hasError() const;
 
@@ -101,17 +87,16 @@ private:
     QScopedPointer<Private> d;
 };
 
-class SortedVaultsModelProxy: public QSortFilterProxyModel {
+class SortedVaultsModelProxy : public QSortFilterProxyModel
+{
     Q_OBJECT
 
 public:
     explicit SortedVaultsModelProxy(QObject *parent);
 
-    bool lessThan(const QModelIndex &left,
-                  const QModelIndex &right) const override;
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
-    bool filterAcceptsRow(int sourceRow,
-                          const QModelIndex &sourceParent) const override;
+    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
 
 public Q_SLOTS:
     QObject *actionsModel() const;
@@ -125,4 +110,3 @@ private:
 };
 
 #endif // include guard
-
